@@ -109,9 +109,7 @@ public class AccountsConnector extends BaseConnector<ArrayDataResponseMto> {
         String rootFolderId = (String) data[10];
         String personal = (String) data[11];
         String transportUrl = (String) data[12];
-        String mailProtocol = (String) data[13];
-        boolean isPop3 = mailProtocol != null && mailProtocol.startsWith("pop3");
-        return new AccountMto(id, accountName, primaryAddress, aliases, transportUrl, rootFolderId, trashFolderName, sentFolderName, draftsFolderName, spamFolderName, archiveFolderId, personal, isPop3);
+        return new AccountMto(id, accountName, primaryAddress, aliases, transportUrl, rootFolderId, trashFolderName, sentFolderName, draftsFolderName, spamFolderName, archiveFolderId, personal);
     }
 
     public static List<MailAccountData> mapToMailAccountData(Object[][] data) {
